@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::WordList;
 
 our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,7 +11,7 @@ use Moose;
 use namespace::autoclean;
 
 use Data::Dmp;
-use Encode qw(is_utf8);
+#use Encode qw(is_utf8);
 
 with (
     'Dist::Zilla::Role::FileMunger',
@@ -53,7 +53,7 @@ sub munge_files {
                 sub {
                     my $word = shift;
                     $stats{num_words}++;
-                    $stats{num_words_contains_unicode}++ if is_utf8($word);
+                    $stats{num_words_contains_unicode}++ if $word =~ /[\x80-\x{10ffff}]/;
                     $stats{num_words_contains_whitespace}++ if $word =~ /\s/;
                     $stats{num_words_contains_nonword_chars}++ if $word =~ /\W/;
                     my $len = length($word);
@@ -95,7 +95,7 @@ Dist::Zilla::Plugin::WordList - Plugin to use when building WordList::* distribu
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2016-01-13.
+This document describes version 0.03 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
